@@ -7,8 +7,8 @@ from zipfile import ZipFile
 system(f"echo {__file__} > /tmp/foo")
 
 distributions = {
-    "darwin": "https://github.com/mulesoft-labs/data-weave-native/releases/download/v1.0.12/dw-1.0.12-macOS.zip",
-    "linux": "https://github.com/mulesoft-labs/data-weave-native/releases/download/v1.0.9/dw-1.0.9-Linux.zip"
+    "darwin": "https://github.com/mulesoft-labs/data-weave-native/releases/download/v1.0.16/dw-1.0.16-macOS",
+    "linux": "https://github.com/mulesoft-labs/data-weave-native/releases/download/v1.0.16/dw-1.0.16-Linux"
 }
 
 if platform not in distributions:
